#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Créé Sept 2024

@auteur: David ALBERTO (www.astrolabe-science.fr)

Tracé de la position du barycentre du Système solaire
au cours du temps.
"""
import matplotlib.pyplot as plt  # graphique
from matplotlib.patches import Ellipse  # disque solaire
import numpy as np  # gestion de données (array)
from skyfield.api import load  # éphémérides astro

plt.rcParams["font.family"] = "Roboto Condensed"  # ou autre police installée
plt.rcParams["font.size"] = 7  # taille de police
an_min = 2004  # année initiale
an_max = 2038  # année finale
pas_an = 2  # intervalle en année entre positions datées

ts = load.timescale()  # chargement d'une échelle de temps Skyfield
t = ts.utc(np.arange(an_min, an_max,0.1))  # liste de dates "continues" (pour ligne continue)
t_discret = ts.utc(range(an_min, an_max+pas_an, pas_an))  # liste de dates espacées
# (Télé)chargement du fichier d'ephémérides de422.bsp (653 MB, période -3000 à 3000). Il existe d'autres fichiers, voir documentation Skyfield
eph = load('de422.bsp')
sun = eph['sun'] # objet Soleil
bary = sun.at(t) # position du Soleil depuis le barycentre du Système solaire.


x, y, z = bary.position.km  # coordonnées cartésiennes en km.

fig, ax = plt.subplots(figsize=(4,4))
ax.set_aspect('equal')  # même échelle en x et en y
ax.set(
       xticks=[],  # suppression graduations en x
       yticks=[],  # suppression graduations en y
       title="position du barycentre du Système solaire",
       )

ax.plot(x,y, lw=0.7)  # tracé de la courbe dans le plan xy

dates = t_discret.utc_strftime('%Y')  # liste d'années discrètes (chaînes de caractères)
xd, yd, zd = sun.at(t_discret).position.km  # coordonnées des positions discrètes

# disque solaire :
rayon_sol = 696340  # en km
soleil = Ellipse((0,0), 2*rayon_sol, 2*rayon_sol,
                 color='orange', ec='k', lw=0.5)
ax.add_patch(soleil)  # affichage du disque solaire

for n in range(len(dates)):
    ax.scatter(xd[n], yd[n], s=4, c='k', zorder=2)  # points discrets
    ax.text(xd[n], yd[n], ' ' + dates[n])  # dates

# affichages des dates limites :
ax.text(0.01,0.01, f'{an_min} - {an_max}',
        transform = ax.transAxes, c='indigo')

fig.savefig('barycentre_soleil.png')
